% T_DEMO - demonstration of capabilities.
%  Short example of capabilities of tidal analysis toolbox.
%
% In this example we a) do nodal corrections for satellites, and
%                    b) Use inference for P1 and K2.
%                    c) Force a fit to a shallow-water constituent

load t_example


echo on

infername=['P1';'K2'];
inferfrom=['K1';'S2'];
infamp=[.33093;.27215];
infphase=[-7.07;-22.40];
[name,fr,tidecon,eout]=t_tide(tuk_elev,'int',1,'start',tuk_time(1),'latitude',69+27/60,...
       'inference',infername,inferfrom,infamp,infphase,'shallow','M10');

pout=t_predic(tuk_time,name,fr,tidecon,69+27/60);

echo off
subplot(211);
plot(tuk_time-datenum(1975,1,0),[tuk_elev pout]);
line(tuk_time-datenum(1975,1,0),tuk_elev-pout,'linewi',2,'color','r');
xlabel('Days in 1975');
ylabel('Elevation (m)');
text(190,5.5,'Original Time series','color','b');
text(190,4.75,'Tidal prediction from Analysis','color',[0 .5 0]);
text(190,4.0,'Original time series minus Prediction','color','r');
title('Demonstations of t\_tide toolbox');

subplot(212);
semilogy([fr,fr]',[.0005*ones(length(fr),1),tidecon(:,1)]','.-');
line(fr,tidecon(:,2),'linestyle',':');
set(gca,'ylim',[.0005 1]);
xlabel('frequency (cph)');
text(fr,tidecon(:,1),name,'rotation',45,'vertical','base');
ylabel('Amplitude (m)');
title('Analyzed lines with 95% significance level');

